require 'uu/os/rest/dto'
require 'uu/os/uesuri'
require 'uu/finman/financialtransaction/financial_transaction_dto'

module UU
  module Finman
    module FinancialTransaction

      # DTO for get attributes command of financial transaction.
      class FinancialTransactionAttributes < FinancialTransactionDTO

        # URI of the financial transaction.<br>
        attr_accessor :uri

        # URI of meta artifact of the financial transaction.
        attr_accessor :meta_artifact_uri

        # Name of the financial transaction.<br>
        attr_accessor :name

        # Code of the financial transaction.<br>
        attr_accessor :code

        # Name of current state of the financial transaction.
        attr_accessor :state_name

        # Type of current state of the financial transaction.
        attr_accessor :state_type

        # Amount of the Financial Transaction without vat.
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        attr_accessor :amount_with_vat

        # Number of credit account.
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        attr_accessor :credit_account_uri

        # UESURI of credit business case from opposite territory.
        # Not set for expost payments and transfers.
        attr_accessor :credit_business_case_from_opposite_territory

        # UESURI of the credit business case
        attr_accessor :credit_business_case_uri

        # Number of debit account.
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        attr_accessor :debit_account_uri

        # UESURI of debit business case from opposite territory.
        # Not set for expost payments and transfers.
        attr_accessor :debit_business_case_from_opposite_territory

        # UESURI of the debit business case.
        attr_accessor :debit_business_case_uri

        # Class of financial transaction (specifies if it is Payment, Transfer, Expost payment or Credit note)
        # @see FinancialTransactionClass
        attr_accessor :financial_transaction_class

        # Pay date of the transaction.
        attr_accessor :pay_date

        # Date of invoicing to the counterparty.
        attr_accessor :protocol_date

        # Probability of payment realization in %.
        attr_accessor :realization_probability

        # Credit vat date of the transaction.
        attr_accessor :credit_vat_date

        # Debit vat date of the transaction.
        attr_accessor :debit_vat_date

        # Code of transaction currency.
        attr_accessor :transaction_currency

        # Creation time of the financial transaction.
        attr_accessor :creation_time

        # Code of credit side currency.
        attr_accessor :credit_side_currency

        # Code of debit side currency.
        attr_accessor :debit_side_currency

        # Date the payment is expected to be payed to.
        attr_accessor :expected_pay_date

        # Code of cost item.
        attr_accessor :cost_item_code

        # Code of income item.
        attr_accessor :income_item_code

        # Name of cost item.
        attr_accessor :cost_item_name

        # Name of income item.
        attr_accessor :income_item_name

        # Date the payment is due to be paid.
        attr_accessor :due_date

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end


        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end


        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end


        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end


        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end


        def credit_business_case_from_opposite_territory
          attributes[:creditBusinessCaseFromOppositeTerritory]
        end

        def credit_business_case_from_opposite_territory=(val)
          attributes[:creditBusinessCaseFromOppositeTerritory] = val
        end


        def credit_business_case_uri
          attributes[:creditBusinessCaseUri]
        end

        def credit_business_case_uri=(val)
          if val
            attributes[:creditBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditBusinessCaseUri] = nil
          end
        end


        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end


        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end


        def debit_business_case_from_opposite_territory
          attributes[:debitBusinessCaseFromOppositeTerritory]
        end

        def debit_business_case_from_opposite_territory=(val)
          attributes[:debitBusinessCaseFromOppositeTerritory] = val
        end


        def debit_business_case_uri
          attributes[:debitBusinessCaseUri]
        end

        def debit_business_case_uri=(val)
          if val
            attributes[:debitBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseUri] = nil
          end
        end


        def financial_transaction_class
          attributes[:financialTransactionClass]
        end

        def financial_transaction_class=(val)
          attributes[:financialTransactionClass] = val
        end

        def pay_date
          attributes[:payDate]
        end

        def pay_date=(val)
          attributes[:payDate] = val
        end


        def protocol_date
          attributes[:protocolDate]
        end

        def protocol_date=(val)
          attributes[:protocolDate] = val
        end


        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def credit_vat_date
          attributes[:creditVatDate]
        end

        def credit_vat_date=(val)
          attributes[:creditVatDate] = val
        end

        def debit_vat_date
          attributes[:debitVatDate]
        end

        def debit_vat_date=(val)
          attributes[:debitVatDate] = val
        end

        def transaction_currency
          attributes[:transactionCurrency]
        end

        def transaction_currency=(val)
          attributes[:transactionCurrency] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def credit_side_currency
          attributes[:creditSideCurrency]
        end

        def credit_side_currency=(val)
          attributes[:creditSideCurrency] = val
        end

        def debit_side_currency
          attributes[:debitSideCurrency]
        end

        def debit_side_currency=(val)
          attributes[:debitSideCurrency] = val
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def cost_item_name
          attributes[:costItemName]
        end

        def cost_item_name=(val)
          attributes[:costItemName] = val
        end

        def income_item_name
          attributes[:incomeItemName]
        end

        def income_item_name=(val)
          attributes[:incomeItemName] = val
        end

        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end

      end
    end
  end
end

